import {deepCopy} from '@/utils/html-util';

/** 纸张方向 */
export const pageDirectionList = [
    // vertical or horizontal
    {label: "垂直方向", value: "Vertical"},
    {label: "水平方向", value: "Horizontal"},
]
/** 字体 */
export const fontList = [
    {code: 'black_body', name: '黑体'},
    {code: 'STFangSong', name: '华文仿宋'},
    {code: 'Microsoft_YaHei', name: '微软雅黑'},
]
/** 边框类型 */
export const borderTypeList = [
    {code: 'none', name: '无', label: '无'},
    {code: 'solid', name: '实线', label: '实线'},
    {code: 'dotted', name: '点状', label: '点状'},
    {code: 'dashed', name: '虚线', label: '虚线'},
    // {code: 'double', name: '双线', label: '双线'},
]
/** 条码类型 */
export const barcodeTypList = [
    {code: 'CODABAR', name: 'Codabar'},
    {code: 'CODE128', name: 'Code128'},
    {code: 'CODE128A', name: 'Code128A'},
    {code: 'CODE128B', name: 'Code128B'},
    {code: 'CODE128C', name: 'Code128C'},
    {code: 'CODE39', name: 'Code39'},
    // {code: 'EAN8', name: 'EAN8'},
    // {code: 'EAN13', name: 'EAN13'},
    // {code: 'EAN8', name: 'EAN8'},
    // {code: 'UPC', name: 'UPC'},
]

export const commonStyle = {
    rotate: 0,
    opacity: 1
}

export const commonAttr = {
    groupStyle: {}, // 当一个组件成为 Group 的子组件时使用
    isLock: false // 是否锁定组件
}

export const elementBands = [
    {name: 'Title', code: 'title', height: 80, isDefaultShow: true},
    {name: 'Page Header', code: 'pageHeader', height: 80, isDefaultShow: true},
    {name: 'Column Header', code: 'columnHeader', height: 30, isDefaultShow: true},
    {name: 'Detail', code: 'detail', height: 125, isDefaultShow: true},
    {name: 'Column Footer', code: 'columnFooter', height: 30, isDefaultShow: true},
    {name: 'Page Footer', code: 'pageFooter', height: 80, isDefaultShow: true},
    {name: 'Last Page Footer', code: 'lastPageFooter', height: 30, isDefaultShow: false},
    {name: 'Summary', code: 'summary', height: 30, isDefaultShow: false},
]

const tableConfigTemplate = {
    rowTemplate: {
        rowNo: 1,
        cols: {
            1: {
                colspan: 1,
                rowspan: 1,
                element: {}
            }
        }
    }
}

const tableInnerElementCodes = ['simpleText', 'textField', 'image', 'barcode', 'qrcode']

// 元素组件
export const elementList = [
    {
        icon: 'fa fa-file-text-o',
        code: 'simpleText',
        name: '静态文本',
        component: 'YvanSimpleText',
        expression: '静态文本',
        style: {
            color: '#000000',
            padding: '0',
            margin: '0',
            fontFamily: 'Microsoft_YaHei',
            lineHeight: 1,
            letterSpacing: '0',
            borderWidth: 0,
            borderRadius: 0,
            borderColor: '#212121',
            borderType: 'none',
            borderPosition: [],
            width: 100,
            height: 30,
            fontSize: 10,
            background: '#FFFFFF',
            rotate: 0,
            justifyContent: 'flex-start',
            alignItems: 'flex-start',
            textStyle: [],
        },
        groupStyle: {}
    },
    {
        icon: 'fa fa-file-text',
        code: 'textField',
        name: '字段文本',
        component: 'YvanTextField',
        expression: '字段文本',
        style: {
            color: '#000000',
            padding: '0',
            margin: '0',
            fontFamily: 'Microsoft_YaHei',
            lineHeight: 1,
            letterSpacing: '0',
            borderWidth: 0,
            borderRadius: 0,
            borderColor: '#212121',
            borderType: 'none',
            borderPosition: [],
            width: 100,
            height: 30,
            fontSize: 10,
            background: '#FFFFFF',
            rotate: 0,
            justifyContent: 'flex-start',
            alignItems: 'flex-start',
            textStyle: [],
        },
        groupStyle: {}
    },
    // {
    //     icon: 'fa fa-text-height',
    //     code: 'long-text',
    //     name: '长文本',
    //     component: 'YvanRichText',
    //     propValue:
    //         '<p><span style="font-size: 16pt;">双击</span><span style="color: rgb(255, 255, 255); background-color: #009688; font-size: 16pt; font-family: 仿宋;">编辑</span><span style="font-size: 16pt;">文本</span></p>',
    //     style: {
    //         width: 500,
    //         height: 200,
    //         fontSize: 12,
    //         background: '#FFFFFF',
    //         rotate: 0,
    //         padding: '0',
    //         borderWidth: 0,
    //         borderPosition: [],
    //         borderColor: '#FFFFFF',
    //     },
    //     groupStyle: {}
    // },
    // {
    //     icon: 'fa fa-th',
    //     code: 'table',
    //     name: '简单表格',
    //     component: 'YvanSimpleTable',
    //     propValue: {},
    //     style: {
    //         width: 'auto',
    //         height: 'auto',
    //         fontSize: 12,
    //         background: '#FFFFFF',
    //         borderWidth: 2,
    //         borderColor: '#212121',
    //         rotate: 0
    //     },
    //     groupStyle: {}
    // },
    {
        icon: 'fa fa-table',
        code: 'complex-table',
        name: '表格',
        component: 'YvanComplexTable',
        propValue: {},
        config: {
            columnNum: 1,
            datasetName: '',
            tableHeader: {
                rows: [
                    {
                        ...deepCopy(tableConfigTemplate.rowTemplate)
                    }
                ]
            },
            columnHeader: {
                rows: [
                    {
                        ...deepCopy(tableConfigTemplate.rowTemplate)
                    }
                ]
            },
            detail: {
                rows: [
                    {
                        ...deepCopy(tableConfigTemplate.rowTemplate)
                    }
                ]
            },
            columnFooter: {
                rows: [
                    {
                        ...deepCopy(tableConfigTemplate.rowTemplate)
                    }
                ]
            },
            tableFooter: {
                rows: [
                    {
                        ...deepCopy(tableConfigTemplate.rowTemplate)
                    }
                ]
            },
        },
        style: {
            width: 'auto',
            height: 'auto',
            fontSize: 12,
            fontFamily: 'default',
            color: '#000000',
            background: '#FFFFFF',
            borderWidth: 2,
            borderColor: '#212121',
            rotate: 0
        },
        groupStyle: {}
    },
    {
        icon: 'fa fa-minus',
        code: 'line',
        name: '直线',
        component: 'YvanLine',
        style: {
            width: 200,
            height: 1,
            background: '#000',
            rotate: 0
        },
        groupStyle: {}
    },
    {
        icon: 'fa fa-square-o',
        code: 'rectangle',
        name: '矩形',
        component: 'YvanRect',
        style: {
            borderRadius: 0,
            borderWidth: 1,
            borderColor: '#212121',
            borderType: 'solid',
            width: 100,
            height: 50,
            background: '#FFFFFF',
            rotate: 0
        },
        groupStyle: {}
    },
    // {
    //     icon: 'fa fa-circle-thin',
    //     code: 'circle',
    //     name: '圆形',
    //     component: 'YvanCircle',
    //     propValue: '',
    //     style: {
    //         borderWidth: 1,
    //         borderColor: '#212121',
    //         borderType: 'solid',
    //         width: 200,
    //         height: 200,
    //         background: '#ffffff',
    //         rotate: 0
    //     },
    //     groupStyle: {}
    // },
    {
        icon: 'fa fa-image',
        code: 'image',
        name: '图片',
        component: 'YvanImage',
        expression: '',
        title: '默认图片',
        config: {
            src: '/default_image.png',
        },
        style: {
            borderRadius: 0,
            borderWidth: 0,
            borderColor: '#212121',
            borderType: 'none',
            width: 50,
            height: 50,
            rotate: 0
        },
        groupStyle: {}
    },
    {
        icon: 'fa fa-barcode',
        code: 'barcode',
        name: '条形码',
        component: 'YvanBarcode',
        expression: '1234567890',
        config: {
            format: 'CODE128',
            displayValue: true,
            textAlign: 'center',
            fontSize: 20
        },
        style: {
            borderType: 'none',
            borderWidth: 0,
            borderColor: '#212121',
            borderRadius: 0,
            width: 100,
            height: 65,
            background: '#fff',
            rotate: 0
        },
        groupStyle: {}
    },
    {
        icon: 'fa fa-qrcode',
        code: 'qrcode',
        name: '二维码',
        component: 'YvanQrcode',
        expression: '1234567890',
        style: {
            width: 100,
            height: 100,
            borderType: 'none',
            borderWidth: 0,
            borderColor: '#212121',
            borderRadius: 0,
            background: '#fff',
            rotate: 0
        },
        groupStyle: {}
    }
]

// 函数组件
export const functionList = [
    {
        icon: 'fa fa-hashtag',
        code: 'pageNumber',
        name: '当前页数',
        component: 'YvanRichText',
        propValue: '',
        style: {
            width: 500,
            height: 200,
            fontSize: 12,
            background: null,
            rotate: 0,
            padding: '0'
        }
    },
    {
        icon: 'fa fa-quora',
        code: 'totalPages',
        name: '总页数',
        component: 'YvanRichText',
        propValue: '',
        style: {
            width: 500,
            height: 200,
            fontSize: 12,
            background: null,
            rotate: 0,
            padding: '0'
        }
    },
    {
        icon: 'fa fa-calendar',
        code: 'currentDate',
        name: '当前日期',
        component: 'YvanRichText',
        propValue: '',
        style: {
            width: 500,
            height: 200,
            fontSize: 12,
            background: null,
            rotate: 0,
            padding: '0'
        }
    },
    {
        icon: 'fa fa-calendar-check-o',
        code: 'currentTime',
        name: '当前时间',
        component: 'YvanRichText',
        propValue: '',
        style: {
            width: 500,
            height: 200,
            fontSize: 12,
            background: null,
            rotate: 0,
            padding: '0'
        }
    },
    {
        icon: 'fa fa-percent',
        code: 'percentage',
        name: '百分比',
        component: 'YvanRichText',
        propValue: '',
        style: {
            width: 500,
            height: 200,
            fontSize: 12,
            background: null,
            rotate: 0,
            padding: '0'
        }
    },
    {
        icon: 'fa fa-hashtag',
        code: 'pageXOfY',
        name: '当前X页,共Y页',
        component: 'YvanRichText',
        propValue: '',
        style: {
            width: 500,
            height: 200,
            fontSize: 12,
            background: null,
            rotate: 0,
            padding: '0'
        }
    },
]

export const componentList = [
    {code: 'element', title: '元素组件', type: 'element', elementList: elementList},
    {code: 'function', title: '系统函数组件', type: 'function', elementList: functionList},
]

export {
    tableConfigTemplate,
    tableInnerElementCodes
}
